<?php
class Kitapcik_Plugin_Initializer extends Zend_Controller_Plugin_Abstract {
    /**
     * @var Zend_Config
     */
    protected static $_config;
 
    /**
     * @var string gecerli ortam
     */
    protected $_env;
 
    /**
     * @var Zend_Controller_Front
     */
    protected $_front;
 
    /**
     * @var application ana klasörü
     */
    protected $_appPath;
 
    /**
     * Constructor
     *
     * Initialize environment, application path, and configuration.
     * 
     * @param  string $env 
     * @param  string|null $appPath
     * @return void
     */
    public function __construct($env, $appPath = null)
    {
        $this->_setEnv($env);
        if (null === $appPath) {
            $appPath = realpath(dirname(__FILE__) . '/../../application');
        }
        $this->_appPath = $appPath;
        $this->_front = Zend_Controller_Front::getInstance();
    }
 
    /**
     * Route startup
     * 
     * @param  Zend_Controller_Request_Abstract $request
     * @return void
     */
    public function routeStartup(Zend_Controller_Request_Abstract $request)
    {
        $this->initDb()
             ->initHelpers()
             ->initView()
             ->initPlugins()
             ->initRoutes();
    }
 
    /**
     *  config objecsini (static) almak
     * 
     * @return Zend_Config
     */
    public static function getConfig()
    {
        return self::$_config;
    }
 
    /**
     * DB objesini olusturmak ve registry ye yazmak
     * 
     * @return Kitapcik_Plugin_Initialize
     */
    public function initDb()
    {
        $config = $this->_getConfig();
        if (!isset($config->db)) {
            return $this;
        }
		//db ayarlarimizi uft8 yapiyoruz
        $config->db->driver_options  =array(PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8');
        $db = Zend_Db::factory($config->db);
        
        //firefox da  firephp kuruluysa db ye gönderilen query ler orada bu satirlarla görünecektir.
       	//sade development asamasinda kullaniniz
        if($this->_env =="development") {
        	$profiler = new Zend_Db_Profiler_Firebug('DB_QUERIES');
        	$profiler->setEnabled(true);
        	$db->setProfiler($profiler);
        }
        Zend_Registry::set('db', $db);
        
        return $this;
    }
 
    /**
     * action helperin bulundugu yeri tespit ediyoruz
     * 
     * @return Kitapcik_Plugin_Initialize
     */
    public function initHelpers()
    {
        Zend_Controller_Action_HelperBroker::addPath(LIB_PATH . '/helpers/action', 'Kitapcik_Helper');
        return $this;
    }
 
    /**
     * view ve layout olusturuyoruz
     * 
     * @return Kitapcik_Plugin_Initialize
     */
    public function initView()
    {
        // Setup View
        $view = new Zend_View();
        $view->doctype('XHTML1_TRANSITIONAL');
		//view helperlerin bulundugu yer
        $view->addHelperPath(LIB_PATH."/helpers/view/",'Kitapcik_View_Helper');
        //jquery
        $view->addHelperPath("ZendX/JQuery/View/Helper", "ZendX_JQuery_View_Helper");
 
        
        $viewRenderer = Zend_Controller_Action_HelperBroker::getStaticHelper('ViewRenderer');
        $viewRenderer->setView($view);
 
        // Layout olustur
        Zend_Layout::startMvc($this->_appPath . '/layouts');
 
        return $this;
    }
 
    /**
     * Initialize plugins
     * 
     * @return Kitapcik_Plugin_Initialize
     */
    public function initPlugins()
    {
        $loader = new Zend_Loader_PluginLoader(array(
            'Kitapcik_Plugin' => LIB_PATH . '/plugins/',
        ));
        return $this;
    }
 
    /**
     * Initialize routes
     * 
     * @return Kitapcik_Plugin_Initialize
     */
    public function initRoutes()
    {
    	
        return $this;
    }
 
    /**
     * config dosyasini okuma
     * 
     * @return Zend_Config
     */
    protected function _getConfig()
    {
        if (null === self::$_config) {
            self::$_config = new Zend_Config_Ini($this->_appPath . '/settings.ini', $this->_env, true);
            self::$_config->root = $this->_appPath;
        }
        return self::$_config;
    }
 
    /**
     * Set environment
     * 
     * @param  string $env 
     * @return void
     */
    protected function _setEnv($env)
    {
        if (!in_array($env, array('development', 'test', 'production'))) {
            $env = 'development';
        }
        $this->_env = $env;
    }
}